Class: Google::Apis::GamesConfigurationV1configuration::ListLeaderboardConfigurationResponse
- Inherits:
-
Object
- Object
- Google::Apis::GamesConfigurationV1configuration::ListLeaderboardConfigurationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/games_configuration_v1configuration/classes.rb,
lib/google/apis/games_configuration_v1configuration/representations.rb,
lib/google/apis/games_configuration_v1configuration/representations.rb
Overview
A ListConfigurations response.
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::GamesConfigurationV1configuration::LeaderboardConfiguration>
The leaderboard configurations.
-
#kind ⇒ String
Uniquely identifies the type of this resource.
-
#next_page_token ⇒ String
The pagination token for the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLeaderboardConfigurationResponse
constructor
A new instance of ListLeaderboardConfigurationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLeaderboardConfigurationResponse
Returns a new instance of ListLeaderboardConfigurationResponse.
381 382 383 |
# File 'lib/google/apis/games_configuration_v1configuration/classes.rb', line 381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::GamesConfigurationV1configuration::LeaderboardConfiguration>
The leaderboard configurations.
Corresponds to the JSON property items
368 369 370 |
# File 'lib/google/apis/games_configuration_v1configuration/classes.rb', line 368 def items @items end |
#kind ⇒ String
Uniquely identifies the type of this resource. Value is always the fixed
string gamesConfiguration#leaderboardConfigurationListResponse.
Corresponds to the JSON property kind
374 375 376 |
# File 'lib/google/apis/games_configuration_v1configuration/classes.rb', line 374 def kind @kind end |
#next_page_token ⇒ String
The pagination token for the next page of results.
Corresponds to the JSON property nextPageToken
379 380 381 |
# File 'lib/google/apis/games_configuration_v1configuration/classes.rb', line 379 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
386 387 388 389 390 |
# File 'lib/google/apis/games_configuration_v1configuration/classes.rb', line 386 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |